diff --git a/.github/.OwlBot.lock.yaml b/.github/.OwlBot.lock.yaml
index 9ee60f7..2567653 100644
--- a/.github/.OwlBot.lock.yaml
+++ b/.github/.OwlBot.lock.yaml
@@ -1,3 +1,3 @@
docker:
- image: gcr.io/repo-automation-bots/owlbot-python:latest
- digest: sha256:aea14a583128771ae8aefa364e1652f3c56070168ef31beb203534222d842b8b
+ image: gcr.io/cloud-devrel-public-resources/owlbot-python:latest
+ digest: sha256:87eee22d276554e4e52863ec9b1cb6a7245815dfae20439712bf644348215a5a
diff --git a/.github/.OwlBot.yaml b/.github/.OwlBot.yaml
index 71a9478..46fc3a9 100644
--- a/.github/.OwlBot.yaml
+++ b/.github/.OwlBot.yaml
@@ -13,7 +13,7 @@
# limitations under the License.
docker:
- image: gcr.io/repo-automation-bots/owlbot-python:latest
+ image: gcr.io/cloud-devrel-public-resources/owlbot-python:latest
deep-remove-regex:
- /owl-bot-staging
diff --git a/.kokoro/build.sh b/.kokoro/build.sh
index e312027..a8a2988 100755
--- a/.kokoro/build.sh
+++ b/.kokoro/build.sh
@@ -41,7 +41,7 @@ python3 -m pip install --upgrade --quiet nox
python3 -m nox --version
# If this is a continuous build, send the test log to the FlakyBot.
-# See https://github.com/googleapis/repo-automation-bots/tree/master/packages/flakybot.
+# See https://github.com/googleapis/repo-automation-bots/tree/main/packages/flakybot.
if [[ $KOKORO_BUILD_ARTIFACTS_SUBDIR = *"continuous"* ]]; then
cleanup() {
chmod +x $KOKORO_GFILE_DIR/linux_amd64/flakybot
diff --git a/.kokoro/test-samples-impl.sh b/.kokoro/test-samples-impl.sh
index 311a8d5..8a324c9 100755
--- a/.kokoro/test-samples-impl.sh
+++ b/.kokoro/test-samples-impl.sh
@@ -80,7 +80,7 @@ for file in samples/**/requirements.txt; do
EXIT=$?
# If this is a periodic build, send the test log to the FlakyBot.
- # See https://github.com/googleapis/repo-automation-bots/tree/master/packages/flakybot.
+ # See https://github.com/googleapis/repo-automation-bots/tree/main/packages/flakybot.
if [[ $KOKORO_BUILD_ARTIFACTS_SUBDIR = *"periodic"* ]]; then
chmod +x $KOKORO_GFILE_DIR/linux_amd64/flakybot
$KOKORO_GFILE_DIR/linux_amd64/flakybot
diff --git a/CHANGELOG.md b/CHANGELOG.md
index fdc8a82..70af584 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,5 +1,12 @@
# Changelog
+### [0.3.3](https://www.github.com/googleapis/python-data-qna/compare/v0.3.2...v0.3.3) (2021-09-24)
+
+
+### Bug Fixes
+
+* add 'dict' annotation type to 'request' ([149f428](https://www.github.com/googleapis/python-data-qna/commit/149f4286f073101a1013ccf07604a0b0c33b8e94))
+
### [0.3.2](https://www.github.com/googleapis/python-data-qna/compare/v0.3.1...v0.3.2) (2021-07-27)
diff --git a/CONTRIBUTING.rst b/CONTRIBUTING.rst
index eab2b7a..0886ec9 100644
--- a/CONTRIBUTING.rst
+++ b/CONTRIBUTING.rst
@@ -50,9 +50,9 @@ You'll have to create a development environment using a Git checkout:
# Configure remotes such that you can pull changes from the googleapis/python-data-qna
# repository into your local repository.
$ git remote add upstream git@github.com:googleapis/python-data-qna.git
- # fetch and merge changes from upstream into master
+ # fetch and merge changes from upstream into main
$ git fetch upstream
- $ git merge upstream/master
+ $ git merge upstream/main
Now your local repo is set up such that you will push changes to your GitHub
repo, from which you can submit a pull request.
@@ -110,12 +110,12 @@ Coding Style
variables::
export GOOGLE_CLOUD_TESTING_REMOTE="upstream"
- export GOOGLE_CLOUD_TESTING_BRANCH="master"
+ export GOOGLE_CLOUD_TESTING_BRANCH="main"
By doing this, you are specifying the location of the most up-to-date
- version of ``python-data-qna``. The the suggested remote name ``upstream``
- should point to the official ``googleapis`` checkout and the
- the branch should be the main branch on that remote (``master``).
+ version of ``python-data-qna``. The
+ remote name ``upstream`` should point to the official ``googleapis``
+ checkout and the branch should be the default branch on that remote (``main``).
- This repository contains configuration for the
`pre-commit `__ tool, which automates checking
@@ -209,7 +209,7 @@ The `description on PyPI`_ for the project comes directly from the
``README``. Due to the reStructuredText (``rst``) parser used by
PyPI, relative links which will work on GitHub (e.g. ``CONTRIBUTING.rst``
instead of
-``https://github.com/googleapis/python-data-qna/blob/master/CONTRIBUTING.rst``)
+``https://github.com/googleapis/python-data-qna/blob/main/CONTRIBUTING.rst``)
may cause problems creating links or rendering the description.
.. _description on PyPI: https://pypi.org/project/google-cloud-data-qna
@@ -234,7 +234,7 @@ We support:
Supported versions can be found in our ``noxfile.py`` `config`_.
-.. _config: https://github.com/googleapis/python-data-qna/blob/master/noxfile.py
+.. _config: https://github.com/googleapis/python-data-qna/blob/main/noxfile.py
We also explicitly decided to support Python 3 beginning with version 3.6.
diff --git a/README.rst b/README.rst
index 24c95ef..f7d8a90 100644
--- a/README.rst
+++ b/README.rst
@@ -15,7 +15,7 @@ and answer service for BigQuery data.
`here `_.
.. |alpha| image:: https://img.shields.io/badge/support-alpha-orange.svg
- :target: https://github.com/googleapis/google-cloud-python/blob/master/README.rst#alpha-support
+ :target: https://github.com/googleapis/google-cloud-python/blob/main/README.rst#alpha-support
.. |pypi| image:: https://img.shields.io/pypi/v/google-cloud-data-qna.svg
:target: https://pypi.org/project/google-cloud-data-qna/
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-cloud-data-qna.svg
@@ -85,5 +85,5 @@ Next Steps
APIs that we cover.
.. _Data QnA Product documentation: https://cloud.google.com/bigquery/docs/dataqna
-.. _repository’s main README: https://github.com/googleapis/google-cloud-python/blob/master/README.rst
+.. _repository’s main README: https://github.com/googleapis/google-cloud-python/blob/main/README.rst
diff --git a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/client.py b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/client.py
index 041b6c3..be21a0c 100644
--- a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/client.py
+++ b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/client.py
@@ -17,7 +17,7 @@
from distutils import util
import os
import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
import pkg_resources
from google.api_core import client_options as client_options_lib # type: ignore
@@ -408,7 +408,7 @@ def __init__(
def suggest_queries(
self,
- request: auto_suggestion_service.SuggestQueriesRequest = None,
+ request: Union[auto_suggestion_service.SuggestQueriesRequest, dict] = None,
*,
retry: retries.Retry = gapic_v1.method.DEFAULT,
timeout: float = None,
@@ -418,7 +418,7 @@ def suggest_queries(
AutoSuggestion tolerance should be less than 1 second.
Args:
- request (google.cloud.dataqna_v1alpha.types.SuggestQueriesRequest):
+ request (Union[google.cloud.dataqna_v1alpha.types.SuggestQueriesRequest, dict]):
The request object. Request for query suggestions.
retry (google.api_core.retry.Retry): Designation of what errors, if any,
should be retried.
diff --git a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/base.py b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/base.py
index f27152f..afc02ce 100644
--- a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/base.py
+++ b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/base.py
@@ -115,7 +115,7 @@ def __init__(
**scopes_kwargs, quota_project_id=quota_project_id
)
- # If the credentials is service account credentials, then always try to use self signed JWT.
+ # If the credentials are service account credentials, then always try to use self signed JWT.
if (
always_use_jwt_access
and isinstance(credentials, service_account.Credentials)
diff --git a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc.py b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc.py
index 6703d90..83ede04 100644
--- a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc.py
+++ b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc.py
@@ -150,16 +150,16 @@ def __init__(
api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
If provided, it overrides the ``host`` argument and tries to create
a mutual TLS channel with client SSL credentials from
- ``client_cert_source`` or applicatin default SSL credentials.
+ ``client_cert_source`` or application default SSL credentials.
client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
Deprecated. A callback to provide client SSL certificate bytes and
private key bytes, both in PEM format. It is ignored if
``api_mtls_endpoint`` is None.
ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
- for grpc channel. It is ignored if ``channel`` is provided.
+ for the grpc channel. It is ignored if ``channel`` is provided.
client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
A callback to provide client certificate bytes and private key bytes,
- both in PEM format. It is used to configure mutual TLS channel. It is
+ both in PEM format. It is used to configure a mutual TLS channel. It is
ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
quota_project_id (Optional[str]): An optional project to use for billing
and quota.
diff --git a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc_asyncio.py b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc_asyncio.py
index 02a5d22..f182915 100644
--- a/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc_asyncio.py
+++ b/google/cloud/dataqna_v1alpha/services/auto_suggestion_service/transports/grpc_asyncio.py
@@ -197,16 +197,16 @@ def __init__(
api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
If provided, it overrides the ``host`` argument and tries to create
a mutual TLS channel with client SSL credentials from
- ``client_cert_source`` or applicatin default SSL credentials.
+ ``client_cert_source`` or application default SSL credentials.
client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
Deprecated. A callback to provide client SSL certificate bytes and
private key bytes, both in PEM format. It is ignored if
``api_mtls_endpoint`` is None.
ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
- for grpc channel. It is ignored if ``channel`` is provided.
+ for the grpc channel. It is ignored if ``channel`` is provided.
client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
A callback to provide client certificate bytes and private key bytes,
- both in PEM format. It is used to configure mutual TLS channel. It is
+ both in PEM format. It is used to configure a mutual TLS channel. It is
ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
quota_project_id (Optional[str]): An optional project to use for billing
and quota.
diff --git a/google/cloud/dataqna_v1alpha/services/question_service/client.py b/google/cloud/dataqna_v1alpha/services/question_service/client.py
index 534591b..1d754dd 100644
--- a/google/cloud/dataqna_v1alpha/services/question_service/client.py
+++ b/google/cloud/dataqna_v1alpha/services/question_service/client.py
@@ -17,7 +17,7 @@
from distutils import util
import os
import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
import pkg_resources
from google.api_core import client_options as client_options_lib # type: ignore
@@ -391,7 +391,7 @@ def __init__(
def get_question(
self,
- request: question_service.GetQuestionRequest = None,
+ request: Union[question_service.GetQuestionRequest, dict] = None,
*,
name: str = None,
retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -401,7 +401,7 @@ def get_question(
r"""Gets a previously created question.
Args:
- request (google.cloud.dataqna_v1alpha.types.GetQuestionRequest):
+ request (Union[google.cloud.dataqna_v1alpha.types.GetQuestionRequest, dict]):
The request object. A request to get a previously
created question.
name (str):
@@ -465,7 +465,7 @@ def get_question(
def create_question(
self,
- request: question_service.CreateQuestionRequest = None,
+ request: Union[question_service.CreateQuestionRequest, dict] = None,
*,
parent: str = None,
question: gcd_question.Question = None,
@@ -476,7 +476,7 @@ def create_question(
r"""Creates a question.
Args:
- request (google.cloud.dataqna_v1alpha.types.CreateQuestionRequest):
+ request (Union[google.cloud.dataqna_v1alpha.types.CreateQuestionRequest, dict]):
The request object. Request to create a question
resource.
parent (str):
@@ -548,7 +548,7 @@ def create_question(
def execute_question(
self,
- request: question_service.ExecuteQuestionRequest = None,
+ request: Union[question_service.ExecuteQuestionRequest, dict] = None,
*,
name: str = None,
interpretation_index: int = None,
@@ -559,7 +559,7 @@ def execute_question(
r"""Executes an interpretation.
Args:
- request (google.cloud.dataqna_v1alpha.types.ExecuteQuestionRequest):
+ request (Union[google.cloud.dataqna_v1alpha.types.ExecuteQuestionRequest, dict]):
The request object. Request to execute an
interpretation.
name (str):
@@ -632,7 +632,7 @@ def execute_question(
def get_user_feedback(
self,
- request: question_service.GetUserFeedbackRequest = None,
+ request: Union[question_service.GetUserFeedbackRequest, dict] = None,
*,
name: str = None,
retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -642,7 +642,7 @@ def get_user_feedback(
r"""Gets previously created user feedback.
Args:
- request (google.cloud.dataqna_v1alpha.types.GetUserFeedbackRequest):
+ request (Union[google.cloud.dataqna_v1alpha.types.GetUserFeedbackRequest, dict]):
The request object. Request to get user feedback.
name (str):
Required. The unique identifier for the user feedback.
@@ -702,7 +702,7 @@ def get_user_feedback(
def update_user_feedback(
self,
- request: question_service.UpdateUserFeedbackRequest = None,
+ request: Union[question_service.UpdateUserFeedbackRequest, dict] = None,
*,
user_feedback: gcd_user_feedback.UserFeedback = None,
update_mask: field_mask_pb2.FieldMask = None,
@@ -714,7 +714,7 @@ def update_user_feedback(
there was none before (upsert).
Args:
- request (google.cloud.dataqna_v1alpha.types.UpdateUserFeedbackRequest):
+ request (Union[google.cloud.dataqna_v1alpha.types.UpdateUserFeedbackRequest, dict]):
The request object. Request to updates user feedback.
user_feedback (google.cloud.dataqna_v1alpha.types.UserFeedback):
Required. The user feedback to
diff --git a/google/cloud/dataqna_v1alpha/services/question_service/transports/base.py b/google/cloud/dataqna_v1alpha/services/question_service/transports/base.py
index f8c5a87..7677868 100644
--- a/google/cloud/dataqna_v1alpha/services/question_service/transports/base.py
+++ b/google/cloud/dataqna_v1alpha/services/question_service/transports/base.py
@@ -119,7 +119,7 @@ def __init__(
**scopes_kwargs, quota_project_id=quota_project_id
)
- # If the credentials is service account credentials, then always try to use self signed JWT.
+ # If the credentials are service account credentials, then always try to use self signed JWT.
if (
always_use_jwt_access
and isinstance(credentials, service_account.Credentials)
diff --git a/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc.py b/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc.py
index fe837f1..272bf11 100644
--- a/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc.py
+++ b/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc.py
@@ -100,16 +100,16 @@ def __init__(
api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
If provided, it overrides the ``host`` argument and tries to create
a mutual TLS channel with client SSL credentials from
- ``client_cert_source`` or applicatin default SSL credentials.
+ ``client_cert_source`` or application default SSL credentials.
client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
Deprecated. A callback to provide client SSL certificate bytes and
private key bytes, both in PEM format. It is ignored if
``api_mtls_endpoint`` is None.
ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
- for grpc channel. It is ignored if ``channel`` is provided.
+ for the grpc channel. It is ignored if ``channel`` is provided.
client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
A callback to provide client certificate bytes and private key bytes,
- both in PEM format. It is used to configure mutual TLS channel. It is
+ both in PEM format. It is used to configure a mutual TLS channel. It is
ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
quota_project_id (Optional[str]): An optional project to use for billing
and quota.
diff --git a/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc_asyncio.py b/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc_asyncio.py
index 083c07d..16c0989 100644
--- a/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc_asyncio.py
+++ b/google/cloud/dataqna_v1alpha/services/question_service/transports/grpc_asyncio.py
@@ -147,16 +147,16 @@ def __init__(
api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
If provided, it overrides the ``host`` argument and tries to create
a mutual TLS channel with client SSL credentials from
- ``client_cert_source`` or applicatin default SSL credentials.
+ ``client_cert_source`` or application default SSL credentials.
client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
Deprecated. A callback to provide client SSL certificate bytes and
private key bytes, both in PEM format. It is ignored if
``api_mtls_endpoint`` is None.
ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
- for grpc channel. It is ignored if ``channel`` is provided.
+ for the grpc channel. It is ignored if ``channel`` is provided.
client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
A callback to provide client certificate bytes and private key bytes,
- both in PEM format. It is used to configure mutual TLS channel. It is
+ both in PEM format. It is used to configure a mutual TLS channel. It is
ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
quota_project_id (Optional[str]): An optional project to use for billing
and quota.
diff --git a/noxfile.py b/noxfile.py
index 03aa2f5..2bf3ffd 100644
--- a/noxfile.py
+++ b/noxfile.py
@@ -84,9 +84,15 @@ def default(session):
constraints_path = str(
CURRENT_DIRECTORY / "testing" / f"constraints-{session.python}.txt"
)
- session.install("asyncmock", "pytest-asyncio", "-c", constraints_path)
-
- session.install("mock", "pytest", "pytest-cov", "-c", constraints_path)
+ session.install(
+ "mock",
+ "asyncmock",
+ "pytest",
+ "pytest-cov",
+ "pytest-asyncio",
+ "-c",
+ constraints_path,
+ )
session.install("-e", ".", "-c", constraints_path)
diff --git a/owlbot.py b/owlbot.py
index 750f343..2cd4ce0 100644
--- a/owlbot.py
+++ b/owlbot.py
@@ -34,6 +34,7 @@
# ----------------------------------------------------------------------------
templated_files = common.py_library(cov_level=98, microgenerator=True)
+python.py_samples(skip_readmes=True)
s.move(templated_files, excludes=[
# the microgenerator has a good coverage rc file
".coveragerc",
diff --git a/renovate.json b/renovate.json
index c048955..c21036d 100644
--- a/renovate.json
+++ b/renovate.json
@@ -1,6 +1,9 @@
{
"extends": [
- "config:base", ":preserveSemverRanges"
+ "config:base",
+ "group:all",
+ ":preserveSemverRanges",
+ ":disableDependencyDashboard"
],
"ignorePaths": [".pre-commit-config.yaml"],
"pip_requirements": {
diff --git a/scripts/fixup_dataqna_v1alpha_keywords.py b/scripts/fixup_dataqna_v1alpha_keywords.py
index da5349a..8b84330 100644
--- a/scripts/fixup_dataqna_v1alpha_keywords.py
+++ b/scripts/fixup_dataqna_v1alpha_keywords.py
@@ -39,12 +39,12 @@ def partition(
class dataqnaCallTransformer(cst.CSTTransformer):
CTRL_PARAMS: Tuple[str] = ('retry', 'timeout', 'metadata')
METHOD_TO_PARAMS: Dict[str, Tuple[str]] = {
- 'create_question': ('parent', 'question', ),
- 'execute_question': ('name', 'interpretation_index', ),
- 'get_question': ('name', 'read_mask', ),
- 'get_user_feedback': ('name', ),
- 'suggest_queries': ('parent', 'scopes', 'query', 'suggestion_types', ),
- 'update_user_feedback': ('user_feedback', 'update_mask', ),
+ 'create_question': ('parent', 'question', ),
+ 'execute_question': ('name', 'interpretation_index', ),
+ 'get_question': ('name', 'read_mask', ),
+ 'get_user_feedback': ('name', ),
+ 'suggest_queries': ('parent', 'scopes', 'query', 'suggestion_types', ),
+ 'update_user_feedback': ('user_feedback', 'update_mask', ),
}
def leave_Call(self, original: cst.Call, updated: cst.Call) -> cst.CSTNode:
@@ -63,7 +63,7 @@ def leave_Call(self, original: cst.Call, updated: cst.Call) -> cst.CSTNode:
return updated
kwargs, ctrl_kwargs = partition(
- lambda a: not a.keyword.value in self.CTRL_PARAMS,
+ lambda a: a.keyword.value not in self.CTRL_PARAMS,
kwargs
)
diff --git a/scripts/readme-gen/templates/install_deps.tmpl.rst b/scripts/readme-gen/templates/install_deps.tmpl.rst
index a0406db..275d649 100644
--- a/scripts/readme-gen/templates/install_deps.tmpl.rst
+++ b/scripts/readme-gen/templates/install_deps.tmpl.rst
@@ -12,7 +12,7 @@ Install Dependencies
.. _Python Development Environment Setup Guide:
https://cloud.google.com/python/setup
-#. Create a virtualenv. Samples are compatible with Python 2.7 and 3.4+.
+#. Create a virtualenv. Samples are compatible with Python 3.6+.
.. code-block:: bash
diff --git a/setup.py b/setup.py
index 89f8b1d..fc26562 100644
--- a/setup.py
+++ b/setup.py
@@ -19,7 +19,7 @@
import os
import setuptools # type: ignore
-version = "0.3.2"
+version = "0.3.3"
package_root = os.path.abspath(os.path.dirname(__file__))
diff --git a/docs/conf.py b/docs/conf.py
index ea8eea5..8ed8fc2 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -76,8 +76,8 @@
# The encoding of source files.
# source_encoding = 'utf-8-sig'
-# The master toctree document.
-master_doc = "index"
+# The root toctree document.
+root_doc = "index"
# General information about the project.
project = "google-cloud-data-qna"
@@ -110,6 +110,7 @@
# directories to ignore when looking for source files.
exclude_patterns = [
"_build",
+ "**/.nox/**/*",
"samples/AUTHORING_GUIDE.md",
"samples/CONTRIBUTING.md",
"samples/snippets/README.rst",
@@ -279,7 +280,7 @@
# author, documentclass [howto, manual, or own class]).
latex_documents = [
(
- master_doc,
+ root_doc,
"google-cloud-data-qna.tex",
"google-cloud-data-qna Documentation",
author,
@@ -314,7 +315,7 @@
# (source start file, name, description, authors, manual section).
man_pages = [
(
- master_doc,
+ root_doc,
"google-cloud-data-qna",
"google-cloud-data-qna Documentation",
[author],
@@ -333,7 +334,7 @@
# dir menu entry, description, category)
texinfo_documents = [
(
- master_doc,
+ root_doc,
"google-cloud-data-qna",
"google-cloud-data-qna Documentation",
author,